@@ -37,12 +37,12 @@ read_branch_count (GIOChannel *infile)
 {
     gchar *line;
     guint len;
-    GError *error = NULL;
     gint count = 0;
     GIOStatus status;
+
     do
     {
-	status = g_io_channel_read_line (infile, &line, &len, NULL, &error);
+	status = g_io_channel_read_line (infile, &line, &len, NULL, NULL);
 	if (status != G_IO_STATUS_NORMAL || len < 2 || 
 	    g_str_has_prefix (line, "#")) 
 	{
@@ -76,7 +76,6 @@ kbd_file_create (gchar *name, gint maxcols)
 		       "<GOK:keyboard name=\"", name, "\" wordcompletion=\"yes\">\n", NULL);
     g_io_channel_write_chars (kbd->io, buf, -1, &bytz, NULL);
     g_free (buf);
-    buf = g_strconcat ("\t<GOK:key ");
     g_io_channel_write_chars (kbd->io, "\t<GOK:key left = \"0\" right = \"1\" top = \"0\" bottom = \"1\" type=\"branchBack\">\n", -1, &bytz, NULL);
     g_io_channel_write_chars (kbd->io, "\t\t<GOK:label type = \"branchBack\">\345\220\216\351\200\200</GOK:label>\n", -1, &bytz, NULL);
     g_io_channel_write_chars (kbd->io, "\t</GOK:key>\n", -1, &bytz, NULL);
@@ -91,9 +90,11 @@ kbd_file_close (KbdFile *kbd)
 {
     gchar *buf;
     gsize bytz;
+
     buf = g_strconcat ("</GOK:keyboard>\n</GOK:GokFile>\n", NULL);
     g_io_channel_write_chars (kbd->io, buf, -1, &bytz, NULL);
-    g_io_channel_close (kbd->io);
+    g_io_channel_unref (kbd->io);
+    g_free (buf);
 }
 
 static void
@@ -157,7 +158,8 @@ create_kbd_from_file (GIOChannel *infile, gchar *kbd_name, gint columns)
 	{
 	    if (error != NULL) 
 	    {
-		g_message (error->message);
+		g_message ("%s", error->message);
+		g_clear_error (&error);
 	    }
 	    continue;
 	}
@@ -198,9 +200,9 @@ create_kbd_from_file (GIOChannel *infile, gchar *kbd_name, gint columns)
 
 int main (int argc, gchar **argv)
 {
-    GError *error;
     GIOChannel *infile;
     gint rows = 4;
+
     if (argc > 2)
     {
 	rows = atoi (argv[2]);
@@ -218,6 +220,7 @@ int main (int argc, gchar **argv)
 	g_message ("using %d columns", cols);
 	g_io_channel_seek_position (infile, 0, G_SEEK_SET, NULL);
 	create_kbd_from_file (infile, argv[1], cols);
+	g_io_channel_unref (infile);
     }
     else
 	g_error ("can't open file %s for reading", argv[1]);
