@@ -1,8 +1,8 @@
 /*
 * gok-editor.c
 *
-* Copyright 2001,2002 Sun Microsystems, Inc.,
-* Copyright 2001,2002 University Of Toronto
+* Copyright 2001-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -87,28 +87,19 @@ void gok_editor_run()
 	
 	/* create the keyboard window */
 	m_pWindowKeyboard = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_object_set_data (GTK_OBJECT (m_pWindowKeyboard), "m_pWindowKeyboard", m_pWindowKeyboard);
 	gtk_window_set_title (GTK_WINDOW (m_pWindowKeyboard), _(TITLE_GOK_EDITOR));
 
-	/* create a window group */
-/*	m_pWindowGroup = gtk_window_group_new();	
-	g_assert (m_pWindowGroup!= NULL);
-	gtk_window_group_add_window(m_pWindowGroup, (GtkWindow*)m_pWindowEditor);
-	gtk_window_group_add_window(m_pWindowGroup, (GtkWindow*)m_pWindowKeyboard);
-	*/
-
 	/* handle the 'delete' event so the keyboard window will not close */
-	gtk_signal_connect (GTK_OBJECT (m_pWindowKeyboard), "delete_event",
-                      GTK_SIGNAL_FUNC (on_editor_keyboard_delete_event),
-                      NULL);
+	g_signal_connect (m_pWindowKeyboard, "delete_event",
+			  G_CALLBACK (on_editor_keyboard_delete_event), NULL);
 	
 	/* TODO - do not allow the user to resize the keyboard window */
 
 	/* add the 'fixed' container to the window */
 	fixed1 = gtk_fixed_new ();
-	gtk_widget_ref (fixed1);
-	gtk_object_set_data_full (GTK_OBJECT (m_pWindowKeyboard), "fixed1", fixed1,
-                            (GtkDestroyNotify) gtk_widget_unref);
+	g_object_ref (fixed1);
+	g_object_set_data_full (G_OBJECT (m_pWindowKeyboard), "fixed1", fixed1,
+				(GDestroyNotify) g_object_unref);
 	gtk_widget_show (fixed1);
 	gtk_container_add (GTK_CONTAINER (m_pWindowKeyboard), fixed1);
 	gtk_widget_show (m_pWindowKeyboard);
@@ -147,6 +138,7 @@ void gok_editor_on_exit ()
 	if (m_bFileModified == TRUE)
 	{
 		/* ask if user wants to lose their changes */
+		/*** TODO: code dup ***/
 		pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
@@ -180,6 +172,7 @@ void gok_editor_new_file ()
 	if (m_bFileModified == TRUE)
 	{
 		/* ask if user wants to lose their changes */
+		/*** TODO: code dup ***/
 		pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
@@ -260,6 +253,7 @@ void gok_editor_open_file()
 	if (m_bFileModified == TRUE)
 	{
 		/* ask if user wants to lose their changes */
+		/*** TODO: code dup ***/
 		pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
@@ -1047,19 +1041,21 @@ gboolean gok_editor_validate_keyboard (GokKeyboard* pKeyboard)
 void gok_editor_message_filename_bad (gchar* Filename)
 {
 	GtkWidget* pDialog;
-	gchar buffer[101];
-
-	sprintf (buffer, _("This is not a valid keyboard filename:\n%s"), Filename);
+	gchar *buffer;
 
+	buffer = g_strdup_printf (_("This is not a valid keyboard filename:\n%s"),
+				  Filename);
+	/*** TODO: code dup ***/
 	pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CLOSE,
-				_(buffer));
+				"%s", buffer);
 
 	gtk_window_set_title (GTK_WINDOW (pDialog), _("Keyboard Filename Invalid"));
 	gtk_dialog_run (GTK_DIALOG (pDialog));
 	gtk_widget_destroy (pDialog);
+	g_free (buffer);
 }
 
 /**
